import { Controller, Get, Post, Body, Patch, Param, Delete, UsePipes, Query } from '@nestjs/common';
import { GoodsService } from '../goods/goods.service';
import { UpdateGoodDto } from '../goods/dto/update-good.dto';
import { ApiOperation, ApiTags, } from '@nestjs/swagger';
import { CreateGoodDto } from 'src/goods/dto/create-good.dto';
import { HttpValidationPipe } from 'src/common/utils/HttpValidationPipe';
import { GoodsListModel } from 'src/goods/goods.model';
import { ApiImplicitQuery } from '@nestjs/swagger/dist/decorators/api-implicit-query.decorator';

@ApiTags('商品管理接口')
@Controller('admin/goods')
export class GoodsController {
  constructor(
    private readonly goodsService: GoodsService
  ) { }

  //商品添加
  @ApiOperation({ summary: '商品添加' })
  @UsePipes(new HttpValidationPipe())
  @Post()
  async create(@Body() createGoodDto: CreateGoodDto) {
    return await this.goodsService.create(createGoodDto);
  }

  //商品列表
  @ApiOperation({ summary: '商品列表' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'pageIndex',
    required: true,
    description: '当前页',
    type: Number,
  })
  @ApiImplicitQuery({
    name: 'pageSize',
    required: true,
    description: '分页',
    type: Number,
  })
  @ApiImplicitQuery({
    name: 'keywords',
    required: false,
    description: '关键词',
    type: String,
  })
  @Get()
  async goodsList(@Query() query: GoodsListModel) {
    return await this.goodsService.goodsList(query);
  }

  //商品详情
  @ApiOperation({ summary: '商品详情' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'id',
    required: true,
    description: '商品ID',
    type: Number,
  })
  @Get(':id')
  async findOne(@Query('id') id: number) {
    return await this.goodsService.findOne(Number(id));
  }

  //商品修改
  @ApiOperation({ summary: '商品修改' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'id',
    required: true,
    description: '商品ID',
    type: Number,
  })
  @Patch(':id')
  async update(@Query('id') id: string, @Body() updateGoodDto: UpdateGoodDto) {
    return await this.goodsService.updateGoods(+id, updateGoodDto);
  }

  //商品删除
  @ApiOperation({ summary: '商品删除' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'id',
    required: true,
    description: '商品ID',
    type: Number,
  })
  @Delete(':id')
  async remove(@Query('id') id: string) {
    return await this.goodsService.remove(+id);
  }
}
