import { Controller, Get, Post, Body, Patch, Param, Delete, UsePipes, Query, UseInterceptors } from '@nestjs/common';
import { ApiOperation, ApiTags } from '@nestjs/swagger';
import { CustomResult, SuccessResult } from 'src/common/utils/result-utils';
import { UserService } from 'src/user/user.service';
import { ChickensService } from './chickens.service';
import { CreateChickenDto } from './dto/create-chicken.dto';
import { UpdateChickenDto } from './dto/update-chicken.dto';
import { CODE } from '../common/code'
import { HttpValidationPipe } from 'src/common/utils/HttpValidationPipe';
import { ApiImplicitQuery } from '@nestjs/swagger/dist/decorators/api-implicit-query.decorator';
import { CacheService } from 'src/redis/redis';
import { getUserTokenKey } from 'src/redis/keys';
import { LoggingInterceptor } from 'src/common/utils/login.interceptor';


@ApiTags('小鸡主体数据接口')
@Controller('chickens')
export class ChickensController {
  constructor(
    private readonly chickensService: ChickensService,
    private readonly userService: UserService,
    private readonly cacheService: CacheService,
  ) { }

  //领取小鸡
  @ApiOperation({ summary: '领取小鸡' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'userid',
    required: true,
    description: '当前用户ID',
    type: Number,
  })
  @Get('draw')
  async create(@Query('userid') userid: number) {
    //小鸡数据初始化
    let createChickenDto: CreateChickenDto = {
      userid: Number(userid),
      token: await this.cacheService.get(getUserTokenKey(userid)),
      schedule: 0,
      eat_start: 0,
      eat_end: 0,
      eat_time: 0,
    };
    //用户数据初始化,有信息则返回
    const initUser = await this.userService.initQuery(createChickenDto)
    if (!initUser || initUser.code != 200) return CustomResult(CODE.CODE_INIT_USER_ERR);

    const init = await this.chickensService.create(createChickenDto);
    if (!init) return CustomResult(CODE.CODE_INIT_PLAYER_ERR);
    return SuccessResult(init);
  }

  // //小鸡信息查询
  // @ApiOperation({ summary: '小鸡信息查询' })
  // @UsePipes(new HttpValidationPipe())
  // @UseInterceptors(LoggingInterceptor)
  // @ApiImplicitQuery({
  //   name: 'userid',
  //   required: true,
  //   description: '当前用户ID',
  //   type: Number,
  // })
  // @Get()
  // async query(@Query('userid') userid: number) {
  //   //小鸡数据初始化
  //   const res = await this.chickensService.chickensInfo(userid);
  //   return SuccessResult(res);
  // }

}
