import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { CODE } from 'src/common/code';
import { CustomResult } from 'src/common/utils/result-utils';
import { OrderlogService } from 'src/orderlog/orderlog.service';
import { Repository } from 'typeorm';
import { CreateChickenDto } from './dto/create-chicken.dto';
import { UpdateChickenDto } from './dto/update-chicken.dto';
import { ChickenEntity } from './entities/chicken.entity';

const prefix = 'chick';
@Injectable()
export class ChickensService {
  constructor(
    @InjectRepository(ChickenEntity)
    private readonly chickensRepository: Repository<ChickenEntity>,
    private readonly orderService: OrderlogService
  ) { }

  /**插入数据 */
  async create(createChickenDto: CreateChickenDto) {
    const info = await this.chickensInfo(createChickenDto.userid);
    if (info) return info;
    createChickenDto.create_time = new Date();
    return await this.chickensRepository.save(createChickenDto);
  }

  /** 查询小鸡信息 */
  async chickensInfo(userid: number) {
    //小鸡信息
    const info = await this.chickensRepository.createQueryBuilder(prefix)
      .select().where(`userid=:userid`, { userid: userid }).getRawOne();
    if (!info) return CustomResult(CODE.CODE_PLAYER_INFO_ERR);
    //小鸡穿戴套装信息
    if (info.chick_ck_suitid == 0) info['suit_info'] = {};
    const suit = await this.orderService.paidGoodsInfo(info.chick_suitid, info.chick_userid);
    info['suit_info'] = suit;
    return info;
  }

  update(id: number, updateChickenDto: UpdateChickenDto) {
    return `This action updates a #${id} chicken`;
  }

}
