import { ChickenStatus } from "src/common/const";
import { Column, CreateDateColumn, Entity, PrimaryGeneratedColumn, UpdateDateColumn } from "typeorm";

/**小鸡主体 */
@Entity('chicken')
export class ChickenEntity {
    @PrimaryGeneratedColumn()
    id?: number;

    @Column({ comment: '用户ID', type: 'int', default: 0, unique: true })
    userid: number;

    @Column({ comment: '套装订单ID', type: 'varchar', default: '' })
    suitid: string;

    @Column({ comment: '碗中剩余饲料', type: 'bigint', default: 0 })
    surplus_fodder: number;

    @Column({ comment: '吃食数量', type: 'bigint', default: 0 })
    eat_fodder: number;

    @Column({ comment: '鸡蛋孵化度', type: 'int' })
    schedule: number;

    @Column({
        comment: '吃食状态(wait待喂食;eating吃食中;wait_fetch待取蛋)',
        type: "enum",
        enum: ChickenStatus,
        default: ChickenStatus.WAIT
    })
    status: string;

    @Column({ comment: '吃食开始(喂饲料)时间', type: 'bigint' })
    eat_start: number;//时间戳

    @Column({ comment: '吃食结束时间', type: 'bigint' })
    eat_end: number;//时间戳

    @Column({ comment: '已经吃了多长时间(单位:s)', type: 'bigint' })
    eat_time: number;

    @CreateDateColumn({ comment: '创建时间', type: 'timestamp' })
    create_time: Date;

    @UpdateDateColumn({ comment: '修改时间', type: 'timestamp' })
    update_time: Date;
}
