import {
  ArgumentMetadata,
  HttpException,
  Injectable,
  Logger,
  PipeTransform,
} from '@nestjs/common';
import { validate } from 'class-validator';
import { plainToClass } from 'class-transformer';

@Injectable()
export class HttpValidationPipe implements PipeTransform<any> {
  private logger = new Logger('HttpValidationPipe');
  private code = 400;//错误自定义code
  constructor(code?: number) {
    // super(options)
    this.code = code;
  }

  async transform(value: any, { metatype }: ArgumentMetadata) {
    if (!metatype || !this.toValidate(metatype)) {
      return value;
    }
    this.logger.debug('HttpValidationPipe.start' + JSON.stringify(value));
    const object = plainToClass(metatype, value);
    const errors = await validate(object);
    if (errors.length > 0) {
      const error = errors[0];
      throw new HttpException(
        `请求参数不合法：${error.value};${JSON.stringify(error.constraints)}`,
        this.code,
      ); //new BadRequestException('Validation failed');
    }
    return object;
  }

  // eslint-disable-next-line @typescript-eslint/ban-types
  private toValidate(metatype: Function): boolean {
    // eslint-disable-next-line @typescript-eslint/ban-types
    const types: Function[] = [String, Boolean, Number, Array, Object];
    return !types.includes(metatype);
  }
}
