/**
 * http请求封装
 */

import fetch from 'node-fetch';

const host = 'http://app.worknote.xyz/';
const sign = '123321';
/**http GET请求 */
export async function httpGetRequest(url: string, params: any) {
    const options = {
        method: 'GET'
    }
    if (params) {
        params['sign'] = sign;//追加签名
        url += "?";
        for (var key in params) {
            url += `${key}=${params[key]}&`;
        }
    }
    url = url.replace(/&{1}$/, '');  // 去掉最后一个拼接的&

    return fetch(host + url, options)
        .then(response => {
            // fetch与ajax(axios)不同，只要服务器有返回值，都是成功，没有返回值才算失败。
            // 所以要在这里进行处理所有返回的结果
            if (!/^(2|3)\d{2}$/.test(String(response.status))) {
                // 失败的状态，非2|3开头的状态，进行处理
                switch (response.status) {
                    case 401:
                        // 权限不够，一般是未登录
                        // ...
                        break;
                    case 403:
                        // 服务器已经接受，但是拒绝访问，通常是登录过期
                        // ...
                        localStorage.removeItem("token");
                        break;
                    case 404:
                        // 找不到资源
                        // ...
                        break;
                }
            }
            // 处理之后，将response的所有数据转换成json，客户端就可以拿到以json格式响应的所有数据
            return response.json();
        })
        .catch(error => {
            // 服务器没有响应才会跳转到这里
            if (!window.navigator.onLine) {
                // 断网处理
                // ...
                return;
            }
            // 什么都没有，返回一个错误
            return Promise.reject(error);
        });
}
/**http POST请求 */
export async function httpPostRequest(url: string, params: any) {
    const options = {
        method: 'POST',
        body: params
    }
    return fetch(host + url + `?sign=${sign}`, options)
        .then(response => {
            // fetch与ajax(axios)不同，只要服务器有返回值，都是成功，没有返回值才算失败。
            // 所以要在这里进行处理所有返回的结果
            if (!/^(2|3)\d{2}$/.test(String(response.status))) {
                // 失败的状态，非2|3开头的状态，进行处理
                switch (response.status) {
                    case 401:
                        // 权限不够，一般是未登录
                        // ...
                        break;
                    case 403:
                        // 服务器已经接受，但是拒绝访问，通常是登录过期
                        // ...
                        localStorage.removeItem("token");
                        break;
                    case 404:
                        // 找不到资源
                        // ...
                        break;
                }
            }
            // 处理之后，将response的所有数据转换成json，客户端就可以拿到以json格式响应的所有数据
            return Promise.resolve(response.json());
        })
        .catch(error => {
            // 服务器没有响应才会跳转到这里
            if (!window.navigator.onLine) {
                // 断网处理
                // ...
                return;
            }
            // 什么都没有，返回一个错误
            return Promise.reject(error);
        });
}