import { Injectable, NestInterceptor, ExecutionContext, CallHandler, HttpException, HttpStatus } from '@nestjs/common';
import { Observable, throwError } from 'rxjs';
import { getUserTokenKey } from 'src/redis/keys';
import { CacheService } from 'src/redis/redis';

@Injectable()
export class LoggingInterceptor implements NestInterceptor {
    constructor(
        private readonly cacheRedis: CacheService
    ) { }
    async intercept(context: ExecutionContext, next: CallHandler): Promise<Observable<any>> {
        const ctx = context.switchToHttp();
        const request = ctx.getRequest();

        const userid = request.query.userid;

        const token = await this.cacheRedis.get(getUserTokenKey(userid));

        const now = Date.now();
        if (!token) {
            return throwError(new HttpException('登录信息错误', HttpStatus.SEE_OTHER))
        }
        return next
            .handle()
            .pipe(
                // tap(() => console.log(`After... ${Date.now() - now}ms`)),
            );
    }
}
