import { HttpException } from "@nestjs/common";

/**
 * 列表数据返回分页信息及数组
 * @data 数据主体
 * @pageIndex 当前页码
 * @pageSize 每页数量
 * @count 总数量
 */
export function DataListResult(data: any[], pageIndex: number, pageSize: number, count: number) {
    return {
        dataList: data,
        pageInfo: {
            totalItems: Number(count),//总条数
            totalPages: (count > 0 ? (Math.floor(count / pageSize) == 0 ? 1 : Math.floor(count / pageSize)) : 1),//总页数
            currentPage: pageIndex,//当前页
            itemCount: data.length,//每页数量
            itemsPerPage: pageSize//输入的每页条数
        }
    };
}

/**
 * 自定义错误信息返回
 * @code 状态码
 * @message 错误信息
 */
export function CustomResult(params: { code: number, message: string }) {
    return { code: params.code, data: '', message: params.message };
    // throw new HttpException({
    //     code: params.code,
    //     error: params.message,
    // }, params.code);
}

/**
 * 自定义错误信息返回
 * @code 状态码
 * @message 错误信息
 */
export function SuccessResult(data?: any) {
    return { code: 200, data: data, message: '请求成功' }
}

export interface ErrResultModel {
    code: number,
    message: string
}
export interface DataResultModel {
    code: number,
    data: any,
    message: string
}