import { Controller, Get, Param, Query, UsePipes } from '@nestjs/common';
import { GoodsService } from './goods.service';
import { ApiOperation, ApiTags } from '@nestjs/swagger';
import { HttpValidationPipe } from 'src/common/utils/HttpValidationPipe';
import { ApiImplicitQuery } from '@nestjs/swagger/dist/decorators/api-implicit-query.decorator';
import { GoodsStatus, GoodsTypes } from 'src/common/const';
import { GoodsListModel } from './goods.model';
import { SuccessResult } from 'src/common/utils/result-utils';

@ApiTags('商品数据接口')
@Controller('goods')
export class GoodsController {
  constructor(private readonly goodsService: GoodsService) { }

  //商品列表
  @ApiOperation({ summary: '商品列表' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'pageIndex',
    required: true,
    description: '当前页',
    type: Number,
  })
  @ApiImplicitQuery({
    name: 'pageSize',
    required: true,
    description: '分页',
    type: Number,
  })
  @Get()
  async goodsList(@Query() query: GoodsListModel) {
    let returnData: any = {};
    //循环商品类型
    const goodsTypes = Object.values(GoodsTypes);
    for (let i = 0; i < goodsTypes.length; i++) {
      query.type = goodsTypes[i];
      const goods = await this.goodsService.apiGoodsList(query)
      returnData[goodsTypes[i]] = goods;
    }
    return SuccessResult(returnData);
  }

  //商品查询
  @ApiOperation({ summary: '商品查询' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'id',
    required: true,
    description: '商品ID',
    type: Number,
  })
  @Get(':id')
  async findOne(@Query('id') id: number) {
    return this.goodsService.findOne(+id, [GoodsStatus.SELLING,GoodsStatus.SELLEND]);
  }

}
