import { ConfigService } from '@nestjs/config';
import { NestFactory } from '@nestjs/core';
import { DocumentBuilder, SwaggerModule } from '@nestjs/swagger';
import { AdminModule } from './admin/admin.module';
import { AppModule } from './app.module';

async function bootstrap() {
  const app = await NestFactory.create(AppModule);

  const configService = app.get(ConfigService);
  const httpPort = configService.get<string>('port');
  console.log(`Linsten port http://192.168.60.11:${httpPort}`);
  //swagger
  const options = new DocumentBuilder()
    .setTitle('【 API 】小鸡游戏接口')
    .setDescription('客户端接口文档')
    .setVersion('1.2.2')
    .build();
  const apiDocument = SwaggerModule.createDocument(app, options);
  SwaggerModule.setup('api', app, apiDocument);
  console.log(`swagger http://192.168.60.11:${httpPort}/api`);

  const adminOptions = new DocumentBuilder()
    .setTitle('【 Admin 】小鸡游戏管理接口')
    .setDescription('管理后台接口文档')
    .setVersion('1.2.2')
    .build();
  const adminDocument = SwaggerModule.createDocument(app, adminOptions, {
    include: [AdminModule]
  });
  SwaggerModule.setup('admin', app, adminDocument);
  console.log(`swagger admin http://192.168.60.11:${httpPort}/admin`);


  await app.listen(httpPort);
}
bootstrap();
