import { GoodsTypes } from "src/common/const";
import { Column, CreateDateColumn, Entity, PrimaryGeneratedColumn, UpdateDateColumn } from "typeorm";

/** 订单主体 */
@Entity('orderlog')
export class OrderlogEntity {

    @PrimaryGeneratedColumn('uuid')
    orderid: string;

    @Column({ comment: '用户ID', type: 'bigint', default: 0 })
    userid: number;

    @Column({ comment: '商品ID', type: 'bigint', default: 0 })
    goods_id: number;

    @Column({
        comment: '商品类型(fodder-饲料;backdrop-背景;prop-道具;suit-套装)',
        type: "enum",
        enum: GoodsTypes,
        default: GoodsTypes.FODDER
    })
    goods_type: string;

    @Column({ comment: '商品价格(购买时)', type: 'bigint' })
    goods_price: number;

    @Column({ comment: '商品属性(如:饲料(克),背景/道具/套装(天)', type: 'bigint' })
    goods_attribute: number;

    @Column({ comment: '商品描述', type: 'varchar', default: '' })
    goods_desc: string;

    @Column({ comment: '商品地址(图片路径)', type: 'varchar', default: '' })
    goods_url: string;

    @CreateDateColumn({ comment: '购买时间', type: 'timestamp' })
    buy_time: Date;

    @CreateDateColumn({ comment: '创建时间', type: 'timestamp' })
    create_time: Date;

    @UpdateDateColumn({ comment: '修改时间', type: 'timestamp' })
    update_time: Date;
}
