import { Controller, Get, Body, Patch, Param, UsePipes, Query, Post } from '@nestjs/common';
import { UserService } from './user.service';
import { UpdateUserDto } from './dto/update-user.dto';
import { ApiOperation, ApiTags } from '@nestjs/swagger';
import { SuccessResult } from 'src/common/utils/result-utils';
import { HttpValidationPipe } from 'src/common/utils/HttpValidationPipe';
import { ApiImplicitQuery } from '@nestjs/swagger/dist/decorators/api-implicit-query.decorator';
import { BuyGoodsUserDto } from './dto/buygoods-user.dto';
import { CreateUserDto } from './dto/create-user.dto';

@ApiTags('用户数据接口')
@Controller('user')
export class UserController {
  constructor(private readonly userService: UserService) { }


  //查询用户信息
  @ApiOperation({ summary: '用户信息查询' })
  @ApiImplicitQuery({
    name: 'userid',
    required: true,
    description: '当前用户ID',
    type: Number,
  })
  @ApiImplicitQuery({
    name: 'userid',
    required: true,
    description: '当前用户ID',
    type: Number,
  })
  @Get('user_info')
  async userInfoQuery(
    @Query() createUserDto: CreateUserDto,
  ) {
    return await this.userService.initQuery(createUserDto);
  }

  //更新用户在线状态
  @ApiOperation({ summary: '更新用户在线状态' })
  @UsePipes(new HttpValidationPipe())
  @ApiImplicitQuery({
    name: 'userid',
    required: true,
    description: '当前用户ID',
    type: Number,
  })
  @Patch(':userid')
  async update(@Query('userid') userid: number, @Body() updateUserDto: UpdateUserDto) {
    return this.userService.update(+userid, updateUserDto);
  }

  //购买商品
  @ApiOperation({ summary: '购买商品' })
  @UsePipes(new HttpValidationPipe())
  @Post('buy')
  async buy(@Body() buyGoodsUserDto: BuyGoodsUserDto) {
    return await this.userService.buy(buyGoodsUserDto);
  }

}
